describe('css', function() {

    describe('set', function() {

        it('should set style property on element', function() {
            var element = $('<div/>'),
                expected = '#f00',
                actually = 'rgb(255, 0, 0)';
            element.css('color', expected);
            var actual = element[0].style.color;
            expect(actual).to.equal(actually);
        });

        it('should set dashed style property on elements', function() {
            var expected = '10px';
            $('#testFragment').css('padding-left', expected);
            var actual = getComputedStyle($('#testFragment')[0]).paddingLeft;
            expect(actual).to.equal(expected);
        });

        it('should set camelCased style property on elements', function() {
            var expected = '10px';
            $('#testFragment').css('paddingRight', expected);
            var actual = getComputedStyle($('#testFragment')[0]).paddingRight;
            expect(actual).to.equal(expected);
        });

        it('should set multiple style property on elements', function() {
            var element = $('#testFragment'),
                expected = ['300', 'italic'];
            element.css({'font-weight': expected[0], 'font-style': expected[1]});
            var actual = [getComputedStyle(element[0]).fontWeight, getComputedStyle(element[0]).fontStyle];
            expect(actual[0]).to.equal(expected[0]);
            expect(actual[1]).to.equal(expected[1]);
        });

        it('should empty style property on element', function() {
            var expected = '';
            $('#testFragment')[0].style.marginBottom = '1px';
            $('#testFragment').css('marginBottom', expected);
            var actual = $('#testFragment')[0].style.marginBottom;
            expect(actual).to.equal(expected);
        });

        it('should not throw when trying to set style property in empty collection', function() {
            var element = $('#not-there'),
                fn = element.css.bind(element, 'color', '#00f');
            expect(fn).not.to.throw(TypeError);
        });

    });

    describe('get', function() {

        it('should get dashed style property from first element', function() {
            var expected = 2;
            $('#testFragment .two').css('zIndex', expected);
            var actual = $('#testFragment [class]').css('z-index');
            expect(actual).to.equal(expected);
        });

        it('should get camelCased style property from first element', function() {
            var expected = '#00f',
                actually = 'rgb(0, 0, 255)';
            $('#testFragment .two').css('background-color', expected);
            var actual = $('#testFragment [class]').css('backgroundColor');
            expect(actual).to.equal(actually);
        });

        it('should not throw when trying to get style property in empty collection', function() {
            var element = $('#not-there'),
                fn = element.css.bind(element),
                actual = element.css('foo');
            expect(fn).not.to.throw(TypeError);
            expect(actual).to.be.undefined;
        });

    });

    it('should provide a chainable API', function() {
        var expected = 'italic',
            element = $('#testFragment').css('font-style', 'inherit').css('font-style', expected),
            actual = getComputedStyle(element[0]).fontStyle;
        expect(actual).to.equal(expected);
    });

});
